Index: /trunk/MagicSoft/Mars/Changelog
===================================================================
--- /trunk/MagicSoft/Mars/Changelog	(revision 4288)
+++ /trunk/MagicSoft/Mars/Changelog	(revision 4289)
@@ -18,4 +18,11 @@
 
                                                  -*-*- END OF LINE -*-*-
+
+
+ 2004/06/12: Markus Gaug
+
+  * msignal/MExtractFixedWindow.cc 
+    - output the number and exact range of extraction to *fLog in the 
+      ReInit(), like it is done by MPedCalcPedRun
 
 
Index: /trunk/MagicSoft/Mars/msignal/MExtractFixedWindow.cc
===================================================================
--- /trunk/MagicSoft/Mars/msignal/MExtractFixedWindow.cc	(revision 4288)
+++ /trunk/MagicSoft/Mars/msignal/MExtractFixedWindow.cc	(revision 4289)
@@ -28,5 +28,6 @@
 //  MExtractFixedWindow
 //
 //  Extracts the signal from a fixed window in a given range.
 //
 //  Call: SetRange(fHiGainFirst, fHiGainLast, fLoGainFirst, fLoGainLast) 
@@ -62,4 +63,7 @@
 //
 // Default constructor. 
+//
+// Calls:
+// - SetRange(fgHiGainFirst, fgHiGainLast, fgLoGainFirst, fgLoGainLast)
 //
 MExtractFixedWindow::MExtractFixedWindow(const char *name, const char *title)
@@ -158,4 +162,12 @@
                               fLoGainFirst, fLoGainLast, fNumLoGainSamples);
 
+
+  *fLog << endl;
+  *fLog << inf << GetDescriptor() << ": Taking " << (int)fNumHiGainSamples
+        << " HiGain FADC samples from slice: " << (int)fHiGainFirst 
+        << " to (including) slice: " << (int)fHiGainLast+(int)fHiLoLast << endl;
+  *fLog << inf << GetDescriptor() << ": Taking " << (int)fNumLoGainSamples
+        << " LoGain FADC samples from slice: " << (int)fLoGainFirst << endl;
+        << " to (including) slice: " << (int)fLoGainLast << endl;
   return kTRUE;
   
@@ -170,4 +182,8 @@
 // - If *ptr is greater than fSaturationLimit, raise sat by 1
 // 
+// - If fHiLoLast is not 0, loop also from logain to (logain+fHiLoLast)
+// - Sum up contents of logain
+// - If *logain is greater than fSaturationLimit, raise sat by 1
+//
 void MExtractFixedWindow::FindSignalHiGain(Byte_t *ptr, Byte_t *logain, Int_t &sum, Byte_t &sat) const
 {
@@ -193,5 +209,4 @@
         sat++;
     }
-
 }
 
@@ -28,5 +28,6 @@
 //  MExtractFixedWindow
 //
-//  Extracts the signal from a fixed window in a given range.
+//  Extracts the signal from a fixed window in a given range by summing up the 
+//  slice contents.
 //
 //  Call: SetRange(fHiGainFirst, fHiGainLast, fLoGainFirst, fLoGainLast) 
